---
name: Feature Request
about: "Suggest a new idea/feature."
title: "[Feature Request] Short Description of New Idea/Feature"
labels: feature
assignees: ""

---

## Description
Please describe what new idea/feature would like to see added to the package.

## Use case
Please elaborate on how your idea/feature request will provide additional value/functionality.
